Skip to contents

Extended selection table (est) with the acoustic data and annotations of the master sound file of synthetic sounds. The synthetic sound files are 2 s long, frequency modulated, and amplitude modulated. The data was created by warbleR::selection_table() from the warbleR package. The re-recorded data generated with these sounds is found in the example object test_sounds_est.

Usage

data(master_est)

Format

Extended selection table object in the warbleR format, which contains annotations and acoustic data.

Marcelo Araya-Salas

See also

Other data sets: test_sounds_est