Skip to contents

Extended selection table (est) of 7 re-recorded synthetic sounds. The synthetic sounds are 2 s long, frequency modulated, amplitude modulated, and were broadcast and re-recorded at 3 distances (1, 10, and 30 m, column distance). The data was created by warbleR::selection_table() from the warbleR package. The master sound file data used to create these test sounds is found in the example object master_est.

Usage

data(test_sounds_est)

Format

Extended selection table object in the warbleR format, which contains annotations and acoustic data.

Marcelo Araya-Salas

See also

Other data sets: master_est